package com.ruoyi.nanjing.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.nanjing.mapper.TBdProductinfoMapper;
import com.ruoyi.nanjing.domain.TBdProductinfo;
import com.ruoyi.nanjing.service.ITBdProductinfoService;
import com.ruoyi.common.core.text.Convert;

/**
 * 产品信息Service业务层处理
 * 
 * @author limy
 * @date 2021-01-25
 */
@Service
public class TBdProductinfoServiceImpl implements ITBdProductinfoService 
{
    @Autowired
    private TBdProductinfoMapper tBdProductinfoMapper;

    /**
     * 查询产品信息
     * 
     * @param ID 产品信息ID
     * @return 产品信息
     */
    @Override
    public TBdProductinfo selectTBdProductinfoById(Long ID)
    {
        return tBdProductinfoMapper.selectTBdProductinfoById(ID);
    }

    /**
     * 查询产品信息列表
     * 
     * @param tBdProductinfo 产品信息
     * @return 产品信息
     */
    @Override
    public List<TBdProductinfo> selectTBdProductinfoList(TBdProductinfo tBdProductinfo)
    {
        return tBdProductinfoMapper.selectTBdProductinfoList(tBdProductinfo);
    }

    /**
     * 新增产品信息
     * 
     * @param tBdProductinfo 产品信息
     * @return 结果
     */
    @Override
    public int insertTBdProductinfo(TBdProductinfo tBdProductinfo)
    {
        return tBdProductinfoMapper.insertTBdProductinfo(tBdProductinfo);
    }

    /**
     * 修改产品信息
     * 
     * @param tBdProductinfo 产品信息
     * @return 结果
     */
    @Override
    public int updateTBdProductinfo(TBdProductinfo tBdProductinfo)
    {
        tBdProductinfo.setUpdateTime(DateUtils.getNowDate());
        return tBdProductinfoMapper.updateTBdProductinfo(tBdProductinfo);
    }

    /**
     * 删除产品信息对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTBdProductinfoByIds(String ids)
    {
        return tBdProductinfoMapper.deleteTBdProductinfoByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除产品信息信息
     * 
     * @param ID 产品信息ID
     * @return 结果
     */
    @Override
    public int deleteTBdProductinfoById(Long ID)
    {
        return tBdProductinfoMapper.deleteTBdProductinfoById(ID);
    }

    @Override
    public List<TBdProductinfo> selectTBdProductinfo() {
        return tBdProductinfoMapper.selectTBdProductinfo();
    }
}
